@@ -8,4 +8,4 @@ class AppMenuItem(zoom.component.DynamicComponent):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        zoom.requires('fontawesome4')
\ No newline at end of file
+        zoom.requires('fontawesome4', 'bootstrap-icons')
